@@ -2,26 +2,40 @@
 
 namespace TsLib\Sso\Controllers;
 
-use App\Http\Controllers\Controller;
+use Illuminate\Foundation\Auth\Access\AuthorizesRequests;
+use Illuminate\Foundation\Bus\DispatchesJobs;
+use Illuminate\Foundation\Validation\ValidatesRequests;
+use Illuminate\Routing\Controller as BaseController;
+
 use Illuminate\Http\Request;
 use Illuminate\Support\Facades\Log;
 use Illuminate\Support\Facades\Auth;
 use Carbon\Carbon;
 
 use TsLib\Sso\Models\SSOToken;
-use TsLib\Sso\Models\CustomerSalesRep;
 
-class SSOController extends Controller
+class SSOController extends BaseController
 {
     //
+    use AuthorizesRequests, DispatchesJobs, ValidatesRequests;
+    
     public function token(Request $request)
     {
         $getToken = SSOToken::where('token', $request->get('t'))->orderBy('created_at', 'DESC')->first();
 
+        if(config('ts-lib-sso.redirect_route_type') == 'name')
+        {
+            $redirect = redirect()->route(config('ts-lib-sso.redirect_route_value'));
+        }
+        else
+        {
+            $redirect = config('ts-lib-sso.redirect_route_value') != null ? redirect(config('ts-lib-sso.redirect_route_value')) : redirect('/');
+        }
+
         if($getToken == null)
         {
             Log::error(sprintf('Se intentó hacer login con una token %s no válida', $request->get('t')));
-            return redirect()->route('home'); //ToDo: cambiar esto a config()
+            return $redirect;
         }
 
         $date = Carbon::now();
@@ -29,12 +43,13 @@ class SSOController extends Controller
         if($date->diffInMinutes($getToken->created_at) > 3)
         {
             Log::error(sprintf('El usuario %s intentó hacer login con una token %s expirada', $getToken->sales_rep_id, $request->get('t')));
-            return redirect()->route('home');//ToDo: cambiar esto a config()
+            return $redirect;
         }
 
-        $user = CustomerSalesRep::find($getToken->sales_rep_id);
+        $user_provider = config('auth.providers.users.model');
+        $user = $user_provider::find($getToken->sales_rep_id);
         Auth::login($user);
 
-        return redirect()->route('home');//ToDo: cambiar esto a config()
+        return $redirect;
     }
 }
